@@ -10,6 +10,15 @@ from sklearn.model_selection import train_test_split
 from sklearn.linear_model import LinearRegression
 from sklearn import metrics
 
+def prep_dataframe(file):
+    sales = pd.read_csv(file)
+    sales['ref'] = sales['ref'].astype('category')
+    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
+    sales['product_number'] = sales['product_number'].astype('category')
+    sales['product_name'] = sales['product_name'].astype('category')
+    return sales
+    
+
 def EOQ(demand, mean, STD, C, Ce, Cs, Ct):
   Qs=math.sqrt(2*Ct*demand/Ce)
   Ts=Qs/demand
@@ -110,11 +119,7 @@ def IOCT(TimeOrderShipped, TimeOrderReceived, NumberofOrdersShipped):
   #print("Internal Order Cycle Time: " + str(r))
 
 def lineplotQtyByMonth(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','quantity']]
     sales_qty = sales_qty.set_index(["date"])
@@ -124,11 +129,7 @@ def lineplotQtyByMonth(file,product_number):
     sns.lineplot(data=sales_qty, x='date',y='quantity').set_title(product_number)
     
 def lineplotTotalCostByMonth(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales['total_cost'] = sales['quantity']*sales['cost']
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','total_cost']]
@@ -139,11 +140,7 @@ def lineplotTotalCostByMonth(file,product_number):
     sns.lineplot(data=sales_qty, x='date',y='total_cost').set_title(product_number)
     
 def lineplotTotalSalesByMonth(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales['total_sales'] = sales['quantity']*sales['price']
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','total_sales']]
@@ -154,11 +151,7 @@ def lineplotTotalSalesByMonth(file,product_number):
     sns.lineplot(data=sales_qty, x='date',y='total_sales').set_title(product_number)
 
 def lineplotAverageCostByMonth(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','cost']]
     sales_qty = sales_qty.set_index(["date"])
@@ -168,11 +161,7 @@ def lineplotAverageCostByMonth(file,product_number):
     sns.lineplot(data=sales_qty, x='date',y='cost').set_title(product_number)
     
 def lineplotAverageSalesPriceByMonth(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','price']]
     sales_qty = sales_qty.set_index(["date"])
@@ -182,11 +171,7 @@ def lineplotAverageSalesPriceByMonth(file,product_number):
     sns.lineplot(data=sales_qty, x='date',y='price').set_title(product_number)
     
 def basicSafetyStock(file,productNumber,safetyDays,leadTimeinDays):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == productNumber]
     sales_qty = sales.set_index(["date"])
     sales_qty = sales_qty.reset_index()
@@ -197,11 +182,7 @@ def basicSafetyStock(file,productNumber,safetyDays,leadTimeinDays):
     print("Reorder Point: "+str(reorder_point))
     
 def basicSafetyStockList(file,safetyDays,leadTime):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     pd.set_option('display.float_format', lambda x: '%.2f' % x)
     result = pd.DataFrame(columns=['product_number', 'product_name', 'safety_stock', 'reorder_point'])
     for pnum in sales.product_number.unique():
@@ -216,11 +197,7 @@ def basicSafetyStockList(file,safetyDays,leadTime):
     print("Saftey Stock and reorder point with basic method", result, sep='\n')
     
 def safetyStockwtServiceRate(file,productNumber,serviceRate,leadTimeInDays):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == productNumber]
     sales_qty = sales.set_index(["date"])
     sales_qty = sales_qty.reset_index()
@@ -235,11 +212,7 @@ def safetyStockwtServiceRate(file,productNumber,serviceRate,leadTimeInDays):
     print("Reorder Point: "+str(reorder_point))
     
 def safetyStockwtServiceRateList(file,serviceRate,leadTimeInDays):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     result = pd.DataFrame(columns=['product_number', 'product_name', 'safety_stock', 'reorder_point'])
     for pnum in sales.product_number.unique():
         sales_prep = sales.loc[sales['product_number'] == pnum]
@@ -257,11 +230,7 @@ def safetyStockwtServiceRateList(file,serviceRate,leadTimeInDays):
     print("Saftey Stock with service rate method method", result, sep='\n')
     
 def cvPerProduct(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','quantity']]
     sales_qty = sales_qty.set_index(["date"])
@@ -271,11 +240,7 @@ def cvPerProduct(file,product_number):
     print(cv)
     
 def linearRegressionPerProduct(file,product_number):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == product_number]
     X = sales['quantity'].values.reshape(-1,1)
     y = sales['price'].values.reshape(-1,1)
@@ -295,11 +260,7 @@ def linearRegressionPerProduct(file,product_number):
     plt.show()
     
 def eoqPerProduct(file,product_number,setupCost,holdingCost):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.loc[sales['product_number'] == product_number]
     sales_qty = sales[['date','quantity']]
     sales_qty = sales_qty.set_index(["date"])
@@ -309,11 +270,7 @@ def eoqPerProduct(file,product_number,setupCost,holdingCost):
     print('EOQ :', EOQ)
     
 def avgQtySoldList(file):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales = sales.dropna()
     pd.set_option('display.float_format', lambda x: '%.2f' % x)
     result = pd.DataFrame(columns=['product_number', 'product_name', 'QTY Sold by Year'])
@@ -351,11 +308,7 @@ def avgQtySoldList(file):
 #     print("Purchasing Metrics", result, sep='\n')
     
 def seasonalityIndexPerProduct(file,product_number,year):
-    sales = pd.read_csv(file)
-    sales['ref'] = sales['ref'].astype('category')
-    sales['date'] = pd.to_datetime(sales['date'],  errors='coerce')
-    sales['product_number'] = sales['product_number'].astype('category')
-    sales['product_name'] = sales['product_name'].astype('category')
+    sales = prep_dataframe(file)
     sales['total_amount'] = sales['quantity']*sales['price']
     sales = sales.loc[sales['product_number'] == product_number]
     sales['year'] = pd.DatetimeIndex(sales['date']).year
