@@ -6,9 +6,7 @@ import seaborn as sns
 import math
 import plotly.graph_objects as go
 
-
-def printStatement(file):
-    pd.set_option('display.float_format', lambda x: '%.2f' % x)
+def prep_dataframe(file):
     statement = pd.read_csv(file)
     statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
     statement.Breakdown = statement.Breakdown.str.replace(',', '')
@@ -16,17 +14,17 @@ def printStatement(file):
     statement['Breakdown'] = statement['Breakdown'].str.lower()
     statement = statement.set_index('Breakdown')
     statement=statement.abs()
+    return statement
+
+
+def printStatement(file):
+    pd.set_option('display.float_format', lambda x: '%.2f' % x)
+    statement = prep_dataframe(file)
     print(statement)
 
 
 def lineplot(file,category):
-    statement = pd.read_csv(file)
-    statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
-    statement.Breakdown = statement.Breakdown.str.replace(',', '')
-    statement.Breakdown = statement.Breakdown.str.replace('&', '')
-    statement['Breakdown'] = statement['Breakdown'].str.lower()
-    statement = statement.set_index('Breakdown')
-    statement=statement.abs()
+    statement = prep_dataframe(file)
 
     plotData = statement.T
     plotData = plotData.reset_index()
@@ -38,14 +36,7 @@ def lineplot(file,category):
     sns.lineplot(data=plotData, x='index',y=category)
 
 def multiLineplot(file,title):
-
-    statement = pd.read_csv(file)
-    statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
-    statement.Breakdown = statement.Breakdown.str.replace(',', '')
-    statement.Breakdown = statement.Breakdown.str.replace('&', '')
-    statement['Breakdown'] = statement['Breakdown'].str.lower()
-    statement = statement.set_index('Breakdown')
-    statement=statement.abs()
+    statement = prep_dataframe(file)
 
     plotData = statement.T
     plotData = plotData.reset_index()
@@ -122,13 +113,7 @@ def calculateMetrics(balanceSheet,incomeStatement):
     print(Ratio)
     
 def bulletChart(file,item):
-    statement = pd.read_csv(file)
-    statement.Breakdown = statement.Breakdown.str.replace(' ', '_')
-    statement.Breakdown = statement.Breakdown.str.replace(',', '')
-    statement.Breakdown = statement.Breakdown.str.replace('&', '')
-    statement['Breakdown'] = statement['Breakdown'].str.lower()
-    statement = statement.set_index('Breakdown')
-    statement=statement.abs()
+    statement = prep_dataframe(file)
     
     data = statement.T
     data = data.reset_index()
